using AGSS.Models.DTOs;
using AGSS.Models.Template;
using AGSS.Services;
using Microsoft.AspNetCore.Mvc;

namespace AGSS.Controllers.Menu;

[ApiController]
[Route("api/[controller]")]
public class MenuController : ControllerBase
{
    private readonly MenuService _menuService;

    public MenuController(MenuService menuService)
    {
        _menuService = menuService;
    }

    /// <summary>
    /// 新增父级菜单
    /// </summary>
    [HttpPost("create-parent")]
    public async Task<ReturnTemplate> CreateParentMenu([FromBody] MenuRequest request)
    {
        return await _menuService.CreateParentMenu(request);
    }

    /// <summary>
    /// 编辑父级菜单
    /// </summary>
    [HttpPut("update-parent")]
    public async Task<ReturnTemplate> UpdateParentMenu([FromBody] MenuRequest request)
    {
        return await _menuService.UpdateParentMenu(request);
    }

    /// <summary>
    /// 新增子级菜单
    /// </summary>
    [HttpPost("create-child")]
    public async Task<ReturnTemplate> CreateChildMenu([FromBody] MenuRequest request)
    {
        return await _menuService.CreateChildMenu(request);
    }

    /// <summary>
    /// 编辑子级菜单
    /// </summary>
    [HttpPut("update-child")]
    public async Task<ReturnTemplate> UpdateChildMenu([FromBody] MenuRequest request)
    {
        return await _menuService.UpdateChildMenu(request);
    }

    /// <summary>
    /// 查询菜单全量返回（树形结构）
    /// </summary>
    [HttpGet("all")]
    public async Task<ReturnTemplate> GetAllMenus()
    {
        return await _menuService.GetAllMenus();
    }

    /// <summary>
    /// 删除菜单（递归删除）
    /// </summary>
    [HttpDelete("delete/{uuid}")]
    public async Task<ReturnTemplate> DeleteMenu(string uuid)
    {
        return await _menuService.DeleteMenu(uuid);
    }
}